@@ -348,27 +348,27 @@ with_mock_api({
   })
 })
 
-test_that("gc_get: studies by efo_uri", {
-  base_url <- '/studies/search/findByEfoUri?uri='
-  uri <- 'http://www.ebi.ac.uk/efo/EFO_0004761'
-  uri_encoded <- URLencode(uri, reserved = TRUE)
-  url <- paste0(base_url, uri_encoded)
-  response <- gc_get(url)
-  expect_is(response, "list")
-  expect_named(response, c('url', 'response_code', 'status', 'content'))
-  expect_identical(response$status, c('OK', 'OK'))
-})
+# test_that("gc_get: studies by efo_uri", {
+#   base_url <- '/studies/search/findByEfoUri?uri='
+#   uri <- 'http://www.ebi.ac.uk/efo/EFO_0004761'
+#   uri_encoded <- URLencode(uri, reserved = TRUE)
+#   url <- paste0(base_url, uri_encoded)
+#   response <- gc_get(url)
+#   expect_is(response, "list")
+#   expect_named(response, c('url', 'response_code', 'status', 'content'))
+#   expect_identical(response$status, c('OK', 'OK'))
+# })
 
-test_that("gc_get: studies by efo_uri", {
-  base_url <- '/efoTraits/search/findByEfoUri?uri='
-  uri <- 'http://www.ebi.ac.uk/efo/EFO_0004761'
-  uri_encoded <- URLencode(uri, reserved = TRUE)
-  url <- paste0(base_url, uri_encoded)
-  response <- gc_get(url)
-  expect_is(response, "list")
-  expect_named(response, c('url', 'response_code', 'status', 'content'))
-  expect_identical(response$status, 'OK')
-})
+# test_that("gc_get: studies by efo_uri", {
+#   base_url <- '/efoTraits/search/findByEfoUri?uri='
+#   uri <- 'http://www.ebi.ac.uk/efo/EFO_0004761'
+#   uri_encoded <- URLencode(uri, reserved = TRUE)
+#   url <- paste0(base_url, uri_encoded)
+#   response <- gc_get(url)
+#   expect_is(response, "list")
+#   expect_named(response, c('url', 'response_code', 'status', 'content'))
+#   expect_identical(response$status, 'OK')
+# })
 
 test_that("gc_get: studies", {
   expect_error(gc_get(
